# Generated by Django 3.1.5 on 2021-01-31 19:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0013_update_report_type_choices"),
    ]

    operations = [
        migrations.AlterField(
            model_name="check",
            name="result",
            field=models.CharField(
                blank=True,
                choices=[
                    ("clear", "Clear"),
                    ("consider", "Consider"),
                    ("unidentified", "Unidentified"),
                ],
                help_text="The final result of the check / reports (from API).",
                max_length=20,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="check",
            name="status",
            field=models.CharField(
                blank=True,
                choices=[
                    ("awaiting_applicant", "Awaiting applicant"),
                    ("awaiting_approval", "Awaiting approval"),
                    ("awaiting_data", "Awaiting data"),
                    ("cancelled", "Cancelled"),
                    ("complete", "Complete"),
                    ("in_progress", "In progress"),
                    ("paused", "Paused"),
                    ("reopened", "Reopened"),
                    ("withdrawn", "Withdrawn"),
                ],
                db_index=True,
                help_text="The current state of the check / report (from API).",
                max_length=20,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="report",
            name="result",
            field=models.CharField(
                blank=True,
                choices=[
                    ("clear", "Clear"),
                    ("consider", "Consider"),
                    ("unidentified", "Unidentified"),
                ],
                help_text="The final result of the check / reports (from API).",
                max_length=20,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="report",
            name="status",
            field=models.CharField(
                blank=True,
                choices=[
                    ("awaiting_applicant", "Awaiting applicant"),
                    ("awaiting_approval", "Awaiting approval"),
                    ("awaiting_data", "Awaiting data"),
                    ("cancelled", "Cancelled"),
                    ("complete", "Complete"),
                    ("in_progress", "In progress"),
                    ("paused", "Paused"),
                    ("reopened", "Reopened"),
                    ("withdrawn", "Withdrawn"),
                ],
                db_index=True,
                help_text="The current state of the check / report (from API).",
                max_length=20,
                null=True,
            ),
        ),
    ]
