# Generated by Django 3.1.3 on 2021-03-04 08:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("onfido", "0016_update_applicant_user_field"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="applicant",
            options={},
        ),
    ]
